.. Flask-Obscure documentation master file, created by
   sphinx-quickstart on Fri Oct 20 13:30:12 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. toctree::
   :hidden:
   :maxdepth: 2

   readme
   api

.. include:: readme.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
